==> sensible_stackables-2.1.1%2B1.21.10-fabric-sources.jar: me/pajic/sensible_stackables/mixin/stack_uncapper/ItemStackMixin.java <==
package me.pajic.sensible_stackables.mixin.stack_uncapper;

import com.llamalad7.mixinextras.sugar.Local;
import me.pajic.sensible_stackables.config.ModConfig;
import net.minecraft.class_124;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_9322;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.ModifyArg;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.List;

@Mixin(class_1799.class)
public abstract class ItemStackMixin implements class_9322 {

    @Shadow
    public abstract int getCount();

    /**
     * @reason Patches the ItemStack codec to accept up to the integer max value, up from 99.
     */
    @ModifyArg(
			//? if fabric
            method = "method_57371",
			//? if neoforge && 1.21.1
			//method = "lambda$static$3",
			//? if neoforge && > 1.21.1
			//method = "lambda$static$1",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/util/ExtraCodecs;intRange(II)Lcom/mojang/serialization/Codec;"
            ),
            index = 1
    )
    private static int uncapStackSize(int original) {
        return ModConfig.CONFIG.uncapStackSize() ? Integer.MAX_VALUE : original;
    }

    /**
     * @reason Shows the exact item count in the item tooltip when the item count in the stack is large,
     * as the regular item stack count is abbreviated and no longer shows the exact value.
     */
    @Inject(
            method = "getTooltipLines",
            at = @At(
                    value = "INVOKE",
                    //? if 1.21.1 {
                    /*target = "Lnet/minecraft/world/item/TooltipFlag;isAdvanced()Z",
                    ordinal = 0
                    *///?} else {
                    target = "Lnet/minecraft/world/item/ItemStack;addDetailsToTooltip(Lnet/minecraft/world/item/Item$TooltipContext;Lnet/minecraft/world/item/component/TooltipDisplay;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/world/item/TooltipFlag;Ljava/util/function/Consumer;)V"
                    //?}
            )
    )
    private void showExactItemCountIfLarge(CallbackInfoReturnable<List<class_2561>> cir, @Local List<class_2561> list) {
        if (getCount() > 999) list.add(class_2561.method_43469("text.sensible_stackables.item_count", getCount())
                .method_27692(class_124.field_1080).method_27692(class_124.field_1056));
    }
}

==> sensible_stackables-2.1.3%2B1.21.1-fabric-sources.jar: me/pajic/sensible_stackables/mixin/stack_uncapper/ItemStackMixin.java <==
package me.pajic.sensible_stackables.mixin.stack_uncapper;

import com.llamalad7.mixinextras.sugar.Local;
import me.pajic.sensible_stackables.config.ModConfig;
import net.minecraft.class_124;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_9322;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.ModifyArg;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

import java.util.List;

@Mixin(class_1799.class)
public abstract class ItemStackMixin implements class_9322 {

    @Shadow
    public abstract int getCount();

    /**
     * @reason Patches the ItemStack codec to accept up to the integer max value, up from 99.
     */
    @ModifyArg(
			//? if fabric
            method = "method_57371",
			//? if neoforge && 1.21.1
			//method = "lambda$static$3",
			//? if neoforge && > 1.21.1
			//method = "lambda$static$1",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/util/ExtraCodecs;intRange(II)Lcom/mojang/serialization/Codec;"
            ),
            index = 1
    )
    private static int uncapStackSize(int original) {
        return ModConfig.CONFIG.uncapStackSize() ? Integer.MAX_VALUE : original;
    }

    /**
     * @reason Shows the exact item count in the item tooltip when the item count in the stack is large,
     * as the regular item stack count is abbreviated and no longer shows the exact value.
     */
    @Inject(
            method = "getTooltipLines",
            at = @At(
                    value = "INVOKE",
                    //? if 1.21.1 {
                    target = "Lnet/minecraft/world/item/TooltipFlag;isAdvanced()Z",
                    ordinal = 0
                    //?} else {
                    /*target = "Lnet/minecraft/world/item/ItemStack;addDetailsToTooltip(Lnet/minecraft/world/item/Item$TooltipContext;Lnet/minecraft/world/item/component/TooltipDisplay;Lnet/minecraft/world/entity/player/Player;Lnet/minecraft/world/item/TooltipFlag;Ljava/util/function/Consumer;)V"
                    *///?}
            )
    )
    private void showExactItemCountIfLarge(CallbackInfoReturnable<List<class_2561>> cir, @Local List<class_2561> list) {
        if (getCount() > 999) list.add(class_2561.method_43469("text.sensible_stackables.item_count", getCount())
                .method_27692(class_124.field_1080).method_27692(class_124.field_1056));
    }
}
